fallintoplace opened a new pull request, #2229:
URL: https://github.com/apache/iceberg-go/pull/2229

   ## What
   - Speed up positional-delete lookup for single integer partition fields.
   
   ## Why
   - Avoid formatting integer partition keys as strings for each delete and 
data file.
   
   ## Implementation
   - Use spec ID, field ID, and integer value as the lookup key.
   - Keep the existing canonical lookup for other partition values.
   
   ## Benchmark
   - Go 1.26.3, Apple M1 Pro, existing selective planner benchmark, median of 5 
runs.
   - 1.026 ms to 0.881 ms per operation (14% faster).
   - Allocations: 10,912 to 8,412 per operation (23% fewer).
   - Bytes: 554,728 to 517,040 per operation (7% fewer).
   


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: [email protected]

For queries about this service, please contact Infrastructure at:
[email protected]


---------------------------------------------------------------------
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]

Reply via email to